#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    Meng xiangguo <mxgnene01@gmail.com>
#
#        H A P P Y    H A C K I N G !
#              _____               ______
#     ____====  ]OO|_n_n__][.      |    |]
#    [________]_|__|________)<     |MENG|
#     oo    oo  'oo OOOO-| oo\_   ~o~~~o~'
# +--+--+--+--+--+--+--+--+--+--+--+--+--+
#                        17/5/27  下午7:54

from __future__ import print_function
import os
import sys
import datetime

'''
参考： https://pypi.python.org/pypi/termcolor
'''
__ALL__ = [ 'colored', 'cprint' ]

VERSION = (1, 1, 0)

ATTRIBUTES = dict(
        list(zip([
            'bold',
            'dark',
            '',
            'underline',
            'blink',
            '',
            'reverse',
            'concealed'
            ],
            list(range(1, 9))
            ))
        )
del ATTRIBUTES['']


HIGHLIGHTS = dict(
        list(zip([
            'on_grey',
            'on_red',
            'on_green',
            'on_yellow',
            'on_blue',
            'on_magenta',
            'on_cyan',
            'on_white'
            ],
            list(range(40, 48))
            ))
        )


COLORS = dict(
            list(zip(['grey','red','green','yellow'],[47, 41, 42, 43]))
        )


END = '\033[0m'


def colored(text, color=None, on_color=None, attrs=None):
    """Colorize text.

    Available text colors:
        red, green, yellow, grey.

    Available text highlights:
        on_red, on_green, on_yellow, on_blue, on_magenta, on_cyan, on_white.

    Available attributes:
        bold, dark, underline, blink, reverse, concealed.

    Example:
        colored('Hello, World!', 'red', 'on_grey', ['grey', 'blink'])
        colored('Hello, World!', 'green')
    """
    if os.getenv('ANSI_COLORS_DISABLED') is None:
        fmt_str = '\033[%d;30;1m%s'
        if color is not None:
            text = fmt_str % (COLORS[color], text)

        if on_color is not None:
            text = fmt_str % (HIGHLIGHTS[on_color], text)

        if attrs is not None:
            for attr in attrs:
                text = fmt_str % (ATTRIBUTES[attr], text)

        text += END
    return text


def cprint(text, color=None, on_color=None, attrs=None, **kwargs):

    print((colored(text, color, on_color, attrs)), **kwargs)


# next bit filched from 1.5.2's inspect.py
def currentframe():
    """Return the frame object for the caller's stack frame."""
    try:
        raise Exception
    except:
        return sys.exc_info()[2].tb_frame.f_back


def findCaller():

    """
    Find the stack frame of the caller so that we can note the source
    file name, line number and function name.
    """
    if hasattr(sys, 'frozen'):  # support for py2exe
        _srcfile = "logging%s__init__%s" % (os.sep, __file__[-4:])
    elif __file__[-4:].lower() in ['.pyc', '.pyo']:
        _srcfile = __file__[:-4] + '.py'
    else:
        _srcfile = __file__

    _srcfile = os.path.normcase(_srcfile)

    f = currentframe()
    # On some versions of IronPython, currentframe() returns None if
    # IronPython isn't run with -X:Frames.
    if f is not None:
        f = f.f_back
    rv = "(unknown file)", 0, "(unknown function)"
    while hasattr(f, "f_code"):
        co = f.f_code
        filename = os.path.normcase(co.co_filename)
        if filename == _srcfile:
            f = f.f_back
            continue
        rv = (co.co_filename, f.f_lineno, co.co_name)
        break
    return rv

class TermColor():
    '''
    支持jenkins 支持输出颜色
    '''
    colormap = dict(
        concern=dict(color='green', attrs=['bold']),
        info=dict(color='grey'),
        warn=dict(color='yellow', attrs=['bold']),
        warning=dict(color='yellow', attrs=['bold']),
        error=dict(color='red'),
        critical=dict(color='red', attrs=['bold']),
    )

    def msg_format(self, mode, msg):
        '''
        获取调用者的 文件名、调用函数、调用行
        '''
        fn, lineno, co_name = findCaller()
        filename = fn.split('/')[-1]
        now_date = str(datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
        msg_simple = ('[-] %s - %s(%s:%s@%s): %s') % (now_date, mode, filename, co_name, str(lineno), msg)

        return msg_simple

    def info(self, msg):
        self._log("info", msg)

    def concern(self, msg):
        self._log("concern", msg)

    def error(self, msg):
        self._log("error", msg)

    def warn(self, msg):
        self._log("warn", msg)

    def _log(self, funcname, msg):
        print(colored(self.msg_format(funcname, msg), **self.colormap[funcname]))


log = TermColor()

if __name__ == '__main__':
    print('Current terminal type: %s' % os.getenv('TERM'))
    print('Test basic colors:')
    cprint('Grey color', 'grey')
    cprint('Red color', 'red')
    cprint('Green color', 'green')
    cprint('Yellow color', 'yellow')
    print(('-' * 78))

    print('Test highlights:')
    cprint('On grey color', on_color='on_grey')
    cprint('On red color', on_color='on_red')
    cprint('On green color', on_color='on_green')
    cprint('On yellow color', on_color='on_yellow')
    cprint('On blue color', on_color='on_blue')
    cprint('On magenta color', on_color='on_magenta')
    cprint('On cyan color', on_color='on_cyan')
    cprint('On white color', color='grey', on_color='on_white')
    print('-' * 78)

    print('Test attributes:')
    cprint('Bold grey color', 'grey', attrs=['bold'])
    cprint('Dark red color', 'red', attrs=['dark'])
    cprint('Underline green color', 'green', attrs=['underline'])
    cprint('Blink yellow color', 'yellow', attrs=['blink'])
    print(('-' * 78))

    print('Test mixing:')
    cprint('Underline red on grey color', 'red', 'on_grey',
            ['underline'])
    cprint('Reversed green on red color', 'green', 'on_red', ['reverse'])




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    Meng xiangguo <mxgnene01@gmail.com>
#
#              _____               ______
#     ____====  ]OO|_n_n__][.      |    |]
#    [________]_|__|________)<     |MENG|
#     oo    oo  'oo OOOO-| oo\_   ~o~~~o~'
# +--+--+--+--+--+--+--+--+--+--+--+--+--+
#                        2017/10/19  上午10:05


import os
import time
import json
import click
import requests
from common.html_report import htmlreporter
from common.termlogcolor import log
from common.tools import (
    assertDictContains,
    prepareStrToDict,
    prepareRequestsParam,
    testLoader,
    fromExcelGetAllCase,
    sendmail
)

def findAllFile(path):
    all_case = []
    for casefile in testLoader(path):
        # 多个case文件进行case 合并
        all_case = all_case + fromExcelGetAllCase(casefile, 'GET') + fromExcelGetAllCase(casefile, 'POST')
    return all_case


def checkCase(*args):
    case_err = False
    if args[3] not in ("POST", 'GET'):
        case_err = True
        log.error("接口的Method 必须是POST、GET，请检查测试用例： %s" % args[0])

    if len(args[4]) <= 0:
        case_err = True
        log.error("确认URL正确，请检查测试用例： %s" % args[0])

    return case_err


def runTests(name, desc, use_yn, method, url, headers, cookies, params, expect_value, func, proxies_proxy):
    headers_dict = prepareStrToDict(headers)
    cookies_dict = prepareStrToDict(cookies)
    if params:
        try:
            params_dict = prepareRequestsParam(params)
        except:
            # params 为json格式
            params_dict = json.dumps(json.loads(params))
            headers_dict['content-type'] = 'application/json'
    else:
        params_dict = {}

    proxies = {
        "http": proxies_proxy,
        "https": proxies_proxy,
    }

    if method == "GET":
        if proxies_proxy:
            response = requests.get(url, headers=headers_dict, cookies=cookies_dict, params=params_dict, proxies=proxies)
        else:
            response = requests.get(url, headers=headers_dict, cookies=cookies_dict, params=params_dict)
    elif method == "POST":
        if proxies_proxy:
            response = requests.post(url, headers=headers_dict, cookies=cookies_dict, data=params_dict, proxies=proxies)
        else:
            response = requests.post(url, headers=headers_dict, cookies=cookies_dict, data=params_dict)

    if func == 'assert_equal':
        error_lists = assertDictContains(expect_value, response.content, u'节点：', err_list=[])
    elif func == 'assert_in':
        error_lists = assertDictContains(json.loads(expect_value), response.json(), u'节点：' , err_list=[])

    return error_lists

@click.command()
@click.option('-c', '--casepath', default='./', help=u'case路径')
@click.option('-m', '--mailto', help=u'收件人列表，使用逗号分割')
@click.option('-o', '--outputpath', default='./', help=u'测试报告输出路径')
@click.option('-p', '--prefix', help=u'邮件内容中的url的前缀')
def main(casepath, mailto, outputpath, prefix):
    '''Excel - driven interface automation framework'''
    time_start = time.time()
    pass_no = fail_no = err_no = 0
    case_error = False
    case_html_output = []

    all_case = findAllFile(casepath)

    if all_case:
        for case in all_case:
            case_error = checkCase(*case)
            try:
                res_lists = []
                res_lists = runTests(*case)
                if res_lists:
                    fail_no += 1
                    res_flag = 0
                    log.error(u"用例：%s - 实际结果与预期结果不一致，测试失败，结果如下：" % case[1])
                    log.error(",".join(res_lists))
                else:
                    pass_no += 1
                    res_flag = 1
                    log.info(u"用例：%s - 实际结果与预期结果一致，测试通过" % case[1])
            except Exception as e:
                err_no += 1
                res_flag = 2
                res_lists.append(u"用例：%s - 执行异常，异常信息:" % case[1])
                log.error("执行异常，信息：%s " % str(e))
            finally:
                for idx1, val1 in enumerate(res_lists):
                    res_lists[idx1] = val1.replace('<', '&lt;').replace('>', '&gt;')

                res_lists = '<br>'.join(res_lists) if len(res_lists) else '测试通过'
                case_html_output.append([case[0], case[1], res_flag, res_lists])

    else:
        log.error('测试用例集合为空！')

    if case_error:
        log.error('测试用合法性检查失败，请检查~')

    time_end = time.time()
    time_cost = time_end - time_start

    log.info("测试完成，通过测试用例数：%s, 失败用例数：%s, 异常用例数：%s, 执行测试用例耗时：%s 秒" % (pass_no, fail_no, err_no, time_cost)  )

    if fail_no > 0 or err_no > 0:
        html_name = 'report%s.html' % str(int(time.time()))
        html_full_name = os.path.join(outputpath, html_name)
        html_report = htmlreporter(html_full_name, case_html_output)
        html_report.make_report()
        sendmail(mailto.split(','), prefix + html_name)

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    Meng xiangguo <mxgnene01@gmail.com>
#
#              _____               ______
#     ____====  ]OO|_n_n__][.      |    |]
#    [________]_|__|________)<     |MENG|
#     oo    oo  'oo OOOO-| oo\_   ~o~~~o~'
# +--+--+--+--+--+--+--+--+--+--+--+--+--+
#                        2017/10/19  下午2:13


REPORT_TITTLE = "测试报告"
REPORT_CONTENT = "自动化测试报告"


# 该文件负责将log转换成html格式的报告
class htmlreporter():
    def __init__(self, fpath, column_values=[], report_title=REPORT_TITTLE, report_content=REPORT_CONTENT):
        self.fpath = fpath
        self.title = report_title

        if isinstance(report_content, (str, basestring, unicode)):
            self.content = report_content.replace('<', '&lt;').replace('>', '&gt;')
        else:
            self.content = REPORT_CONTENT

        if isinstance(column_values, list):
            self.column_values = column_values
        else:
            self.column_values = []

        self.table = self.make_table()

    # 自动生成html网页的table模块
    def make_table(self):
        table_begin = '''
            <table class="table">
            <tr>
                <th>用例名称</th>
                <th width="200">测试用例说明</th>
                <th>执行结果</th>
                <th width="600">测试结果详细信息</th>
            </tr>
            '''
        table_end = '''</table>'''
        tr_list = []
        pass_no = fail_no = err_no = 0
        for idx, val in enumerate(self.column_values):
            # 协程处理时结果顺序不确定，不再设置默认用例名称
            # case_name=val[0].replace('<','&lt;').replace('>','&gt;') if val[0] else '用例'+str(idx+1)
            case_name = self.encodeutf8(val[0].replace('<', '&lt;').replace('>', '&gt;') if val[0] else '')
            case_content = self.encodeutf8(val[1].replace('<', '&lt;').replace('>', '&gt;') if val[1] else '测试通过')
            if val[2] == 0:
                case_res = '测试失败'
                fail_no += 1
            elif val[2] == 1:
                case_res = '测试通过'
                pass_no += 1
            else:
                case_res = '执行异常'
                err_no += 1
            case_msg = self.encodeutf8(val[3] if val[3] else '测试通过')
            tr_str = '''<tr>
                            <td>%s</td>
                            <td>%s</td>
                            <td>%s</td>
                            <td>
                                <input type="button" value="查看" id="b%d" onClick="showElement('b%d','t%d')"/>
                                <p id="t%d" style="line-height:20px;display:none">%s</p>
                            </td>
                        </tr>
                    ''' % (case_name, case_content, case_res, idx, idx, idx, idx, case_msg)
            tr_list.append(tr_str)
        table_val = '\r\n'.join(tr_list)
        table_count = '''<tr>
                            <td colspan="4">
                                </p>执行结果：用例总数-%d; 通过-%d ; 失败-%d; 异常-%d;</p>
                            </td>
                        </tr>
                    ''' % (len(self.column_values), pass_no, fail_no, err_no)
        return table_begin + table_val + table_count + table_end

    def encodeutf8(self, strname):
        '''对字符串进行处理，始终输出str 类型'''
        if isinstance(strname, unicode):
            strname = strname.encode('utf8')
        elif isinstance(strname, str):
            strname = strname
        else:
            raise TypeError("value not unicode or str!")

        return strname

    # 生成网页源码
    def make_report(self):
        with open(self.fpath, 'w') as f:
            htmlstr = '''
                <!DOCTYPE html>
                <html>
                <head>
                    <meta charset="utf-8">
                    <title>%s</title>
                    <style type="text/css">
                        body,table{
                            font-size:12px;
                        }
                        table{
                            table-layout:fixed;
                            empty-cells:show;
                            border-collapse: collapse;
                            margin:0 auto;
                        }
                        td{
                            height:30px;
                        }
                        .table{
                            border:1px solid #cad9ea;
                            color:#666;
                        }
                        .table th {
                            background-repeat:repeat-x;
                            height:30px;
                        }
                        .table td,.table th{
                            border:1px solid #cad9ea;
                            padding:0 1em 0;
                        }
                        .table tr.alter{
                            background-color:#f5fafe;
                        }
                    </style>
                    <script type="text/javascript">
                    //控制控件展开、收起
                    function showElement(id1,id2){
                        if (document.getElementById(id1).value=="查看"){
                            document.getElementById(id2).style.display="block";
                            document.getElementById(id1).value="收起";
                            }
                        else {
                            document.getElementById(id2).style.display="none";
                            document.getElementById(id1).value="查看";
                            }
                        }
                    </script>
                </head>
                <body>
                <h1 align="center" style="color:#cad9ea;font-size:16px;">===================================================</h1>
                <h1 align="center" style="color:#666;font-size:16px;">%s</h1>
                <h1 align="center" style="color:#cad9ea;font-size:16px;">===================================================</h1>
                    <div>
                        %s
                    </div>
                </body>
                </html>
                ''' % (self.title, self.content, self.table)
            f.write(htmlstr)


if __name__ == "__main__":
    case_res = [['测试用例1', '姓名输入中文', 1, '测试通过'],
                ['测试用例2', '姓名输入英文', 0,
                 '''节点:/data/goods_id:预期值：167755&lt;type 'int'&gt;实际值：167756&lt;type 'unicode'&gt;对比不一致<br>节点:/data/goods_id:预期值：167755&lt;type 'int'&gt;实际值：167756&lt;type 'unicode'&gt;对比不一致<br>节点:/data/goods_id:预期值：167755&lt;type 'int'&gt;实际值：167756&lt;type 'unicode'&gt;对比不一致'''],
                ['测试用例3', '姓名输入数字', 0, '测试通过'],
                ['测试用例4', '姓名输入中文+英文', 1, '测试通过']]
    h = htmlreporter(r"/Users/Daling/mxg/git/github/itester/result/report.html", case_res)
    h.make_report()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    Meng xiangguo <mxgnene01@gmail.com>
#
#        H A P P Y    H A C K I N G !
#              _____               ______
#     ____====  ]OO|_n_n__][.      |    |]
#    [________]_|__|________)<     |MENG|
#     oo    oo  'oo OOOO-| oo\_   ~o~~~o~'
# +--+--+--+--+--+--+--+--+--+--+--+--+--+
#                        17/6/13  下午5:25

import os
import sys
import glob
import xlrd
import logging

logging.basicConfig(level=logging.INFO,
                    format='[%(asctime)s] - %(process)d - %(levelname)s - %(module)s.%(funcName)s:%(lineno)d - %(message)s')

def fromExcelGetAllCase(fname, method='GET'):
    logging.debug('from %s get all case' % fname)
    bk = xlrd.open_workbook(fname)
    try:
        sh = bk.sheet_by_index(0)
    except:
        logging.error("no sheet in %s named Sheet1" % fname)

    return [tuple(sh.row_values(i)) for i in range(2, sh.nrows) if sh.cell_value(i, 3).upper() == method and sh.cell_value(i, 2).upper() == 'Y']


def testLoader(path, pattern="test_*.xlsx"):
    os.chdir(path)
    return glob.glob(pattern)


def assertDictContains(expect_data, real_data, path='', err_list=[]):
    ''' dict ，list， sting 比对'''
    if isinstance(expect_data, (list, tuple)):
        for index, value in enumerate(expect_data):
            try:
                if not isinstance(value, (list, dict, tuple)):
                    # decode to unicode for diff
                    if isinstance(value, str):
                        value = value.decode('utf-8')

                    if value == real_data[index]:
                        continue
                    else:
                        err_list.append("%s.%s" % (path, str(index)))
                else:
                    err_list = assertDictContains(value, real_data[index], path + '.' + str(index), err_list)
            except Exception, e:
                logging.error(str(e))
    elif isinstance(expect_data, dict):
        for key, value in expect_data.items():
            try:
                if not isinstance(value, (list, dict, tuple)):
                    # decode to unicode for diff
                    if isinstance(value, str):
                        value = value.decode('utf-8')

                    if value == real_data[key]:
                        continue
                    else:
                        err_list.append("%s.%s" % (path, key))
                else:
                    err_list = assertDictContains(value, real_data[key], "%s.%s" % (path, key), err_list)
            except Exception as e:
                logging.error(str(e))
    else:
        if not expect_data.decode('utf-8') == real_data.decode('utf-8'):
            err_list.append("%s.%s" % (path, expect_data))

    return err_list


def prepareStrToDict(strname, ofs='\n'):
    '''
    固定格式的string 转化成 dict

    utoken: 10364121-18687-a133c50e-f3b1-4dd4-967d-b49f034916ae
    key1: values1
    :return {'utoken': '10364121-18687-a133c50e-f3b1-4dd4-967d-b49f034916ae','key1': 'values1'}
    '''
    r_dict = dict()
    if strname:
        for header in strname.split(ofs):
            h = header.split(":")
            r_dict[h[0].strip()] = h[1].strip()

    return r_dict


def prepareRequestsParam(param, ofs='&'):
    '''
    对 requests 的 post 参数进行格式化

    Usage:
        >>> param =  "id=123145&id=123133&aaa=bbb"
        >>> preparePostParam(param)
        (('id', '123145'), ('id', '123133'), ('aaa', 'bbb'))
        >>> param =""
        >>> preparePostParam(param)
        {}
    '''
    if param:
        return tuple([(i.split("=")[0], i.split("=")[1]) for i in param.split(ofs)])
    else:
        return {}

def sendmail(send_to, text, attachment=''):
    import smtplib
    from os.path import basename
    from email.mime.application import MIMEApplication
    from email.mime.multipart import MIMEMultipart
    from email.mime.text import MIMEText
    from email.utils import COMMASPACE, formatdate
    from socket import gethostname

    send_from = 'sysadmin@%s' % (gethostname())
    text = """Greetings,

Please see your test report %s .

Thank you!

[%s]
    """ % (text, gethostname() )
    msg = MIMEMultipart()
    msg['From'] = send_from
    msg['To'] = COMMASPACE.join(send_to)
    msg['Date'] = formatdate(localtime=True)
    msg['Subject'] = u'自动化测试报告'

    msg.attach(MIMEText(text))

    if attachment:
        with open(attachment, "rb") as f:
            name = basename(attachment)
            part = MIMEApplication(f.read(), Name=name)
            part['Content-Disposition'] = 'attachment; filename="%s"' % name
            msg.attach(part)

    if sys.platform.startswith('linux'):
        smtp = smtplib.SMTP('127.0.0.1')
    else:
        smtp = smtplib.SMTP()
        smtp.connect('', 25)
        smtp.login('', '')

    smtp.sendmail(send_from, send_to, msg.as_string())
    smtp.close()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    Meng xiangguo <mxgnene01@gmail.com>
#
#              _____               ______
#     ____====  ]OO|_n_n__][.      |    |]
#    [________]_|__|________)<     |MENG|
#     oo    oo  'oo OOOO-| oo\_   ~o~~~o~'
# +--+--+--+--+--+--+--+--+--+--+--+--+--+
#                        2017/10/16  下午5:47

import os
import nose
import json
import requests
from nose.tools import assert_equal
from common.parameterized import parameterized
from common.tools import assertDictContains, prepareStrToDict, prepareRequestsParam, testLoader, fromExcelGetAllCase

TEST_GET_CASE = TEST_POST_CASE = []

basepath = os.path.dirname(os.path.abspath(__file__))

for casefile in testLoader(os.path.join(basepath, 'testcase')):
    # 多个case文件进行case 合并
    TEST_GET_CASE = TEST_GET_CASE + fromExcelGetAllCase(casefile, 'GET')
    TEST_POST_CASE = TEST_POST_CASE + fromExcelGetAllCase(casefile, 'POST')


class test_iterster():
    '''
    测试的主入口类
    '''
    @parameterized.expand(TEST_GET_CASE)
    def test_get(self, name, desc, use_yn, method, url, headers, cookies, params, expect_value, func, proxies_proxy):
        '''
        GET 方法的接口的测试
        :param name: case 名称
        :param desc: case的详细描述
        :param method: GET/POST
        :param url: 调用的接口
        :param headers: h1: v1\n h2: v2
        :param cookies: c1: v1\n c2: v2
        :param params: key1=value1&key2=value2
        :param expect_value: 预计返回值
        :param func:assert_equal - 预计返回值和实际返回值相等/assert_in - 实际返回值包含预计返回值
        :param proxies_proxy - 代理设置
        '''
        headers_dict = prepareStrToDict(headers)
        cookies_dict = prepareStrToDict(cookies)
        if params:
            params_dict = prepareRequestsParam(params)
        else:
            params_dict = {}

        proxies = {
            "http": proxies_proxy,
            "https": proxies_proxy,
        }

        if proxies_proxy:
            response = requests.get(url, headers=headers_dict, cookies=cookies_dict, params=params_dict,
                                    proxies=proxies)
        else:
            response = requests.get(url, headers=headers_dict, cookies=cookies_dict, params=params_dict)

        if func == 'assert_equal':
            assert_equal(expect_value, response.content)
        elif func == 'assert_in':
            error_lists = assertDictContains(json.loads(expect_value), response.json(), err_list=[])
            if len(error_lists) > 0:
                raise AssertionError(",".join(error_lists))
            else:
                return

    @parameterized.expand(TEST_POST_CASE)
    def test_post(self, name, desc, use_yn, method, url, headers, cookies, params, expect_value, func, proxies_proxy):
        '''
        POST 方法的接口的测试
        :param name: case 名称
        :param desc: case的详细描述
        :param method: GET/POST
        :param url: 调用的接口
        :param headers: h1: v1\n h2: v2
        :param cookies: c1: v1\n c2: v2
        :param param: key1=value1&key2=value2
        :param expect_value: 预计返回值
        :param func:assert_equal - 预计返回值和实际返回值相等/assert_in - 实际返回值包含预计返回值
        :param proxies_proxy - 代理设置
        '''
        headers_dict = prepareStrToDict(headers)
        cookies_dict = prepareStrToDict(cookies)

        proxies = {
            "http": proxies_proxy,
            "https": proxies_proxy,
        }

        try:
            params_dict = prepareRequestsParam(params)
        except:
            params_dict = json.dumps(json.loads(params))
            headers_dict['content-type'] = 'application/json'

        if proxies_proxy:
            response = requests.post(url, headers=headers_dict, cookies=cookies_dict, data=params_dict, proxies=proxies)
        else:
            response = requests.post(url, headers=headers_dict, cookies=cookies_dict, data=params_dict)

        if func == 'assert_equal':
            assert_equal(json.loads(expect_value), response.json())
        elif func == 'assert_in':
            error_lists = assertDictContains(json.loads(expect_value), response.json(), err_list=[])
            if len(error_lists) > 0:
                raise AssertionError(",".join(error_lists))
            else:
                return


if __name__ == '__main__':
    nose.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    Meng xiangguo <mxgnene01@gmail.com>
#
#              _____               ______
#     ____====  ]OO|_n_n__][.      |    |]
#    [________]_|__|________)<     |MENG|
#     oo    oo  'oo OOOO-| oo\_   ~o~~~o~'
# +--+--+--+--+--+--+--+--+--+--+--+--+--+
#                        2017/10/18  下午7:13

import os
import sys
import setuptools
from version import __VERSION__

def _setup():
    setuptools.setup(
        name='itester',
        version=__VERSION__,
        description='Excel - driven interface automation framework',
        author='Xiangguo Meng',
        author_email='mxgnene01@gmail.com',
        install_requires=['requests', 'click', 'xlrd'],
        packages=['itester'],
        license='LICENSE',
        url='https://github.com/mxgnene01/itester',
        include_package_data=True,
        long_description=open('README.md').read(),
        entry_points={
            'console_scripts': [
                'itester=itester.itester:main',
                ]
            }
    )

def main():
    if len(sys.argv) > 1:
        if sys.argv[1] == 'publish':
            os.system('make publish')
            sys.exit()
        elif sys.argv[1] == 'release':
            if len(sys.argv) < 3:
                type_ = 'patch'
            else:
                type_ = sys.argv[2]
            assert type_ in ('major', 'minor', 'patch')

            os.system('bumpversion --current-version {} {}'
                      .format(__VERSION__, type_))
            sys.exit()

    _setup()


if __name__ == '__main__':
    main()
